function sxi_files, time0, time1, nfiles=nfiles,  $ 
  level0=level0, level1=level1, graphics=graphics, $
  ngdc=ngdc, goesn=goesn, full_path=full_path, verbose=verbose
;+
;   Name: sxi_files
;
;   Purpose: return sxi filnames
;
;   Input Paramters:
;      time0 - vector of desired times or start time of range
;      time1 - stop time if range desired
;
;   Keyword Parameters:
;      nfiles (output) - number of files returned
;      level0 (switch) - if set, return level0 names
;      level1 (switch) - if set, return level1 names (default)
;      graphics (switch) - if set, return graphics file names (*.png)
;      ngdc (switch) - if set, use direct NGDC socket listing (not catalog)
;      goesn - GOES sat# desired (default=12) 
;      full_path (switch) - if set, return full path (def is just file name)
; 
;   Calling Sequence:
;      sxifiles=sxi_files(time0,time1 [/level0, /graphics, nfiles=nfiles]
;
;   Calling Examples:
;      sxifiles=sxi_files('12:30 2-dec-2000','14:00 3-dec-2000') ; level1 in range
;      sxifiles=sxi_files(eitindex) ; sxi closest to input EIT index (times)
;
;   History:
;      11-Jan-2003 - S.L.Freeland - from mdi_files/eit_files analog
;
;   Method:
;      Two options:
;         Use SSW sxi catalog 
;         Direct listing via sockets->ngdc (via DMZarro socket package)
;
;  Restrictions:
;    Only /NGDC (direct socket listing) option available for now
;    (which I'll use to generate and enable catalog option asap...) 
;-


ngdc=keyword_set(ngdc)
ssw_sxi_catalog=1-ngdc            ; default - use catalog
;                                 ; (maybe default ngdc for time0/time1 ~recent? tbd)
full_path=keyword_set(full_path)  ; include full path (def=just filename)
verbose=keyword_set(verbose)      ;

nfiles=0                          ; initialize success/match count to failure...
if (1-ngdc) or (1-since_version('5.4')) then begin
   box_message,'Currently requires /NGDC switch (and IDL V>=5.4) '
   return,''
endif

if not keyword_set(goesn) then goesn=12              ; which GOES sat?
sgn=strtrim(goesn,2)

sxidata=concat_dir('$SSWDB','sxig'+sgn)              ; future use

sxilog='SXIG'+strtrim(goesn,2)+'_TOP_HTTP'           ; future use
sxi_server=get_logenv(sxilog)                           

case 1 of 
   sxi_server ne '':                                ;pre assigned
   ngdc: begin
         sxi_server='http://sxi2.ngdc.noaa.gov'     ;in setup.sxig12_env??
         sxi_proxy='http://beluga.ngdc.noaa.gov'    ;ditto
   endcase
   else: begin 
      box_message,'Only /NGDC or $SXIGn_TOP_HTTP supported, returning
      return,'' 
   endcase
endcase
      
toppath='/archive/fits'        ; hardcoded for now - 'nuther sxi env?

; type of file desired (level0, level1, or graphics)
fexten='.FTS'
tfilter=''
case 1 of 
   keyword_set(level0):   tfilter='AA_'+sgn
   keyword_set(level1):   tfilter='BB_'+sgn
   keyword_set(graphics): fexten='.PNG' 
   else: tfilter='BB_'+sgn                 ; default Level1 FITS
endcase

sfilter='*SXI*'+tfilter+'*'+fexten+'*'          ; implied search pattern
;
; generate time grid (maps to subdirectories YYYY/MM/DD )
case n_params() of 
   1: tgrid=anytim(time0,/ecs,/date_only)
   2: tgrid=anytim(timegrid(time0,reltime(time1,/days),/day),/date_only,/ecs)
   else: begin
      box_message,'Supply time(s) or time range...'
      return,''
   endcase
endcase

case 1 of
   ssw_sxi_catalog:                        ; not yet implemented
   else: begin 
      pathgrid=concat_dir(toppath,tgrid)    ; uniq subdirectories ..YYYY/MM/DD
      a=obj_new('http') 
      a->hset,proxy=sxi_proxy
      a->open,sxi_server
      listall=''
      for i=0,n_elements(pathgrid)-1 do begin 
         if verbose then box_message,'Listing>> ' + pathgrid(i)
         a->list,pathgrid(i),listx
         listall=[temporary(listall),listx]
      endfor
      ss=where(strmatch(listall,sfilter),nfiles)
      if nfiles eq 0 then begin 
         box_message,'No SXI files match your times and/or filters, returning...'
         return,''
      endif
      retval='SXI'+strextract(listall(ss),'<A HREF="SXI',fexten+'">')+fexten
      ftimes=file2time(retval,out='int')        
      if full_path then $
         retval=concat_dir(concat_dir(toppath,anytim(ftimes,/ecs,/date_only)),retval)
      case n_params() of
         1: begin                            ; time(s) - get closest matches
            ss=tim2dset(ftimes,anytim(time0,/int))
            retval=retval(ss)
         endcase
         2: begin                            ; range 
            ss=sel_timrange(ftimes,anytim(time0,/int),anytim(time1,/int))
            retval=retval(ss)
         endcase
         else: box_message,'No way to get here...'
      endcase
      nfiles=n_elements(retval)
   endcase
endcase

return,retval
end
